# ![](artworks/logo-full.png)

![Python package](https://github.com/fy0/slim/workflows/Python%20package/badge.svg)
[![PyPI version](https://badge.fury.io/py/slim.svg)](https://badge.fury.io/py/slim)
[![codecov](https://codecov.io/gh/fy0/slim/branch/master/graph/badge.svg)](https://codecov.io/gh/fy0/slim)
[![Maintainability](https://api.codeclimate.com/v1/badges/308e653d0aa234a83c25/maintainability)](https://codeclimate.com/github/fy0/slim/maintainability)

A Web framework provides instant restful api for your database.

* Based on ASGI.

* Instant restful api for your database model.

* Automatic api document (rendered by [redoc](https://github.com/Redocly/redoc)).

* Form validate by [schematics](https://github.com/schematics/schematics)

* Access control supported

* CLI to create project

* Test friendly


## SDK

- [TypeScript/JavaScript](https://github.com/fy0/slim-tools)


## Links

- [Homepage](https://github.com/fy0/slim)
- [Document](https://fy0.github.io/slim/)


## Contributors
- [fy](https://github.com/fy0)
- [leexuanhe](https://github.com/leexuanhe)
- [0xn0ne](https://github.com/0xn0ne)
- [hlx70375](https://github.com/hlx70375)
- [CYY666666](https://github.com/CYY666666)


## Projects

- [Icarus](https://github.com/fy0/Icarus) A opensource forum project write with python3 and vue.js
